pyobject_to_fill_model_any

Function pyobject_to_fill_model_any 

pub fn pyobject_to_fill_model_any(
    obj: &Bound<'_, PyAny>,
) -> PyResult<FillModelAny>
Extracts a Python fill model object into a Rust FillModelAny.

Errors

Returns an error if obj is not a supported built-in fill model binding.