pub fn pyobject_to_fill_model_any(
obj: &Bound<'_, PyAny>,
) -> PyResult<FillModelAny>Expand description
Extracts a Python fill model object into a Rust FillModelAny.
Errors
Returns an error if obj is not a supported built-in fill model binding.