pub fn pyobject_to_fill_model_handle(
obj: &Bound<'_, PyAny>,
) -> PyResult<FillModelHandle>Expand description
Extracts a Python fill model object into a runtime FillModelHandle.
Errors
Returns an error if obj is neither a supported built-in model nor a Python object with
is_limit_filled and is_slipped methods.